import allure

from service.app_a.asserts.order.rights.asserts_order_rights_rightsmanager import AssertsOrderRightsRightsmanager
from service.app_a.apis.order.rights import apis_order_rights_rightsmanager


class FunsOrderRightsRightsmanager(AssertsOrderRightsRightsmanager):
    @allure.step(title="自动生成权益ID-Y")
    def order_rights_rightsmanager_createid(self, _assert=True,  **kwargs):
        """
            url=/order/rights/rightsManager/createId
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rights_rightsmanager.order_rights_rightsmanager_createid(**_kwargs)

        self.assert_order_rights_rightsmanager_createid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="查询互斥关系接口-Y")
    def order_rights_rightsmanager_getrelation(self, rightsId="$None$", _assert=True,  **kwargs):
        """
            url=/order/rights/rightsManager/getRelation
                params: rightsId :  :
                params: headers : 请求头
        """
        rightsId = self.get_list_choice(rightsId, list_or_dict=None, key="rightsId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rights_rightsmanager.order_rights_rightsmanager_getrelation(**_kwargs)

        self.assert_order_rights_rightsmanager_getrelation(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="权益 - 分页查询-Y")
    def order_rights_rightsmanager_page(self, rightsName="$None$", modelCode="$None$", size=10, effectiveEndDate="$None$", status="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/order/rights/rightsManager/page
                params: size :  :
                params: current :  :
                params: rightsName :  :
                params: status :  :
                params: modelCode :  :
                params: effectiveEndDate :  :
                params: headers : 请求头
        """
        rightsName = self.get_list_choice(rightsName, list_or_dict=None, key="rightsName")
        modelCode = self.get_list_choice(modelCode, list_or_dict=None, key="modelCode")
        effectiveEndDate = self.get_list_choice(effectiveEndDate, list_or_dict=None, key="effectiveEndDate")
        status = self.get_list_choice(status, list_or_dict=None, key="status")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rights_rightsmanager.order_rights_rightsmanager_page(**_kwargs)

        self.assert_order_rights_rightsmanager_page(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="权益订单 - 查询-Y")
    def order_rights_rightsmanager_getrightslist(self, rightsName="$None$", effectiveStartDate="$None$", modelId="$None$", status="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/rights/rightsManager/getRightsList
                params: rightsName : string : 权益名称
                params: status : integer : 权益状态(0未生效，1已生效)
                params: modelId : string : 车型代码
                params: effectiveStartDate : string : 权益生效时间
                params: headers : 请求头
        """
        rightsName = self.get_value_choice(rightsName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        effectiveStartDate = self.get_value_choice(effectiveStartDate, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        modelId = self.get_value_choice(modelId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rights_rightsmanager.order_rights_rightsmanager_getrightslist(**_kwargs)

        self.assert_order_rights_rightsmanager_getrightslist(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="权益-新增权益-Y")
    def order_rights_rightsmanager_insert(self, rightsId="$None$", modelCode="$None$", rightsName="$None$", rightsType="$None$", orderType="$None$", effectiveStartDate="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/rights/rightsManager/insert
                params: effectiveStartDate : text : 权益生效时间 -- 开始
                params: rightsId : text : 权益ID
                params: rightsName : text : 权益名称
                params: rightsType : text : 权益类型
                params: modelCode : text : 车型代码
                params: orderType : text : 关联订单类型code
                params: headers : 请求头
        """
        rightsId = self.get_value_choice(rightsId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        modelCode = self.get_value_choice(modelCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        rightsName = self.get_value_choice(rightsName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        rightsType = self.get_value_choice(rightsType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        orderType = self.get_value_choice(orderType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        effectiveStartDate = self.get_value_choice(effectiveStartDate, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rights_rightsmanager.order_rights_rightsmanager_insert(**_kwargs)

        self.assert_order_rights_rightsmanager_insert(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="权益-修改权益-Y")
    def order_rights_rightsmanager_update(self, rightsName="$None$", rightsId="$None$", Content="$None$", effectiveStartDate="$None$", effectiveEndDate="$None$", Relation="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/rights/rightsManager/update
                params: rightsName : string : 权益名称
                params: rightsId : string : 权益主键
                params: Content : string : 权益描述
                params: effectiveStartDate : string : 权益生效时间
                params: effectiveEndDate : string : 权益生效时间-结束
                params: Relation : string : 互斥关系
                params: headers : 请求头
        """
        rightsName = self.get_value_choice(rightsName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        rightsId = self.get_value_choice(rightsId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        Content = self.get_value_choice(Content, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        effectiveStartDate = self.get_value_choice(effectiveStartDate, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        effectiveEndDate = self.get_value_choice(effectiveEndDate, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        Relation = self.get_value_choice(Relation, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rights_rightsmanager.order_rights_rightsmanager_update(**_kwargs)

        self.assert_order_rights_rightsmanager_update(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="权益-获取权益详情-Y")
    def order_rights_rightsmanager_rightsbyid(self, id="$None$", _assert=True,  **kwargs):
        """
            url=/order/rights/rightsManager/rightsById
                params: id :  :
                params: headers : 请求头
        """
        id = self.get_list_choice(id, list_or_dict=None, key="id")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rights_rightsmanager.order_rights_rightsmanager_rightsbyid(**_kwargs)

        self.assert_order_rights_rightsmanager_rightsbyid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="权益-通过id更新权益生效状态-Y")
    def order_rights_rightsmanager_updatestatusbyid(self, rightsId="$None$", status="$None$", _assert=True,  **kwargs):
        """
            url=/order/rights/rightsManager/updateStatusById
                params: rightsId :  :
                params: status :  :
                params: headers : 请求头
        """
        rightsId = self.get_list_choice(rightsId, list_or_dict=None, key="rightsId")
        status = self.get_list_choice(status, list_or_dict=None, key="status")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rights_rightsmanager.order_rights_rightsmanager_updatestatusbyid(**_kwargs)

        self.assert_order_rights_rightsmanager_updatestatusbyid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





from service.app_a.funs.order.funs_order_rightsorder import FunsOrderRightsorder
from service.app_a.funs.order.funs_order_mainorder import FunsOrderMainorder
from service.app_a.funs.order.funs_order_order import FunsOrderOrder
from service.app_a.funs.order.funs_order_rights import FunsOrderRights
from service.app_a.funs.order.funs_order_testdrive import FunsOrderTestdrive
from service.app_a.funs.order.funs_order_freeorder import FunsOrderFreeorder


class FunsOrder(FunsOrderRightsorder, FunsOrderMainorder, FunsOrderOrder, FunsOrderRights, FunsOrderTestdrive, FunsOrderFreeorder):
    pass




import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/essay/delete/")
def content_essay_delete_(essayId=None, headers=None, **kwargs):
    """
    专题-后台APP专题文章删除-Y
    up_time=1675736702

    params: essayId :  : 文章id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0 成功 1失败
    params: msg : string : 
    params: data : null : 
    """
    _method = "POST"
    _url = "/content/essay/delete/{essayId}"
    _url = get_url(_url, locals())

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
        "essayId": essayId,  # 文章id
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/essay/searchByKey")
def content_essay_searchbykey(current=None, size=None, Key=None, headers=None, **kwargs):
    """
    专题-后台App文章关键词搜索-Y
    up_time=1675736722

    params: Key :  : 关键词
    params: size :  : 条数
    params: current :  : 当前页
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/content/essay/searchByKey"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "Key": Key,  # 关键词
        "size": size,  # 条数
        "current": current,  # 当前页
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/essay/checkList")
def content_essay_checklist(subjectId=None, size=None, keyWord=None, CreateTimeSortType=None, endTime=None, recommend=None, PublishTimeSortType=None, status=None, author=None, essayId=None, StatusSortType=None, startTime=None, current=None, headers=None, **kwargs):
    """
    后台管理-内容审核列表1030-Y
    up_time=1675736061

    params: essayId :  : 文章主键
    params: keyWord :  : 文章搜索关键字
    params: author :  : 作者
    params: startTime :  : 搜索开始时间
    params: endTime :  : 搜索结束时间
    params: subjectId :  : 专题主键
    params: status :  : 文章状态1：待上架2：已上架3：已下架4：已删除 5 待审核 6 审核不通过 7草稿
    params: size :  : 每页条数
    params: current :  : 当前页数
    params: recommend :  : 是否推荐 1：推荐页0：非推荐页
    params: PublishTimeSortType :  : 发布时间排序方式 默认倒序，正序  ASC 倒序 DESC
    params: CreateTimeSortType :  : 创建时间排序方式 默认倒序，  正序  ASC 倒序 DESC
    params: StatusSortType :  : 状态排序方式 默认倒序，  正序  ASC 倒序 DESC
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              pages : number : 
    """
    _method = "GET"
    _url = "/content/essay/checkList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 文章主键
        "keyWord": keyWord,  # 文章搜索关键字
        "author": author,  # 作者
        "startTime": startTime,  # 搜索开始时间
        "endTime": endTime,  # 搜索结束时间
        "subjectId": subjectId,  # 专题主键
        "status": status,  # 文章状态1：待上架2：已上架3：已下架4：已删除 5 待审核 6 审核不通过 7草稿
        "size": size,  # 每页条数
        "current": current,  # 当前页数
        "recommend": recommend,  # 是否推荐 1：推荐页0：非推荐页
        "PublishTimeSortType": PublishTimeSortType,  # 发布时间排序方式 默认倒序，正序  ASC 倒序 DESC
        "CreateTimeSortType": CreateTimeSortType,  # 创建时间排序方式 默认倒序，  正序  ASC 倒序 DESC
        "StatusSortType": StatusSortType,  # 状态排序方式 默认倒序，  正序  ASC 倒序 DESC
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/essay/list")
def content_essay_list(subjectId=None, size=None, keyWord=None, CreateTimeSortType=None, endTime=None, recommend=None, PublishTimeSortType=None, status=None, author=None, essayId=None, StatusSortType=None, startTime=None, current=None, headers=None, **kwargs):
    """
    后台管理-内容管理列表1030-Y
    up_time=1675736044

    params: essayId :  : 文章主键
    params: keyWord :  : 文章搜索关键字
    params: author :  : 作者
    params: startTime :  : 搜索开始时间
    params: endTime :  : 搜索结束时间
    params: subjectId :  : 专题主键
    params: status :  : 文章状态1：待上架2：已上架3：已下架4：已删除 5 待审核 6 审核不通过 7草稿
    params: size :  : 每页条数
    params: current :  : 当前页数
    params: recommend :  : 是否推荐 1：推荐页0：非推荐页
    params: PublishTimeSortType :  : 发布时间排序方式 默认倒序，正序  ASC 倒序 DESC
    params: CreateTimeSortType :  : 创建时间排序方式 默认倒序，  正序  ASC 倒序 DESC
    params: StatusSortType :  : 状态排序方式 默认倒序，  正序  ASC 倒序 DESC
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              pages : number : 
    """
    _method = "GET"
    _url = "/content/essay/list"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 文章主键
        "keyWord": keyWord,  # 文章搜索关键字
        "author": author,  # 作者
        "startTime": startTime,  # 搜索开始时间
        "endTime": endTime,  # 搜索结束时间
        "subjectId": subjectId,  # 专题主键
        "status": status,  # 文章状态1：待上架2：已上架3：已下架4：已删除 5 待审核 6 审核不通过 7草稿
        "size": size,  # 每页条数
        "current": current,  # 当前页数
        "recommend": recommend,  # 是否推荐 1：推荐页0：非推荐页
        "PublishTimeSortType": PublishTimeSortType,  # 发布时间排序方式 默认倒序，正序  ASC 倒序 DESC
        "CreateTimeSortType": CreateTimeSortType,  # 创建时间排序方式 默认倒序，  正序  ASC 倒序 DESC
        "StatusSortType": StatusSortType,  # 状态排序方式 默认倒序，  正序  ASC 倒序 DESC
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/essay/add")
def content_essay_add(subjectId=None, videoUrl=None, essayType=None, recommend=None, essPicUrl=None, publishType=None, author=None, essayId=None, title=None, content=None, status=None, publishTime=None, headers=None, **kwargs):
    """
    后台管理-新建&修改内容1030-Y
    up_time=1675736497

    params: essayId : string : 文章主键
    params: title : string : 标题
    params: author : string : 作者
    params: publishType : number : 发布类型1：立即发布2：定时发布
    params: publishTime : string : 发布时间
    params: content : string : 富文本内容
    params: status : string : 状态 新增状态为待审核 1：待上架2：已上架 3 ：已下架4：已删除 5待审核 6 审核不通过 7 草稿
    params: essayType : string : 文章类型1：图文2：视频
    params: subjectId : array : 专题主键
              type : string : None
    params: recommend : number : 是否推荐 1：推荐页0：非推荐页
    params: essPicUrl : string : 封面
    params: videoUrl : string : 视频路径
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/essay/add"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 文章主键
        "title": title,  # 标题
        "author": author,  # 作者
        "publishType": publishType,  # 发布类型1：立即发布2：定时发布
        "publishTime": publishTime,  # 发布时间
        "content": content,  # 富文本内容
        "status": status,  # 状态 新增状态为待审核 1：待上架2：已上架 3 ：已下架4：已删除 5待审核 6 审核不通过 7 草稿
        "essayType": essayType,  # 文章类型1：图文2：视频
        "subjectId": subjectId,  # 专题主键
        "recommend": recommend,  # 是否推荐 1：推荐页0：非推荐页
        "essPicUrl": essPicUrl,  # 封面
        "videoUrl": videoUrl,  # 视频路径
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/essay/createId")
def content_essay_createid( headers=None, **kwargs):
    """
    文章-生成文章主键-Y
    up_time=1675736244

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : string : 主键
    """
    _method = "GET"
    _url = "/content/essay/createId"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/essay/getById")
def content_essay_getbyid(essayId=None, headers=None, **kwargs):
    """
    后台管理-内容详情1030-Y
    up_time=1675736219

    params: essayId :  : 文章主键
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : object : 
              essayId : string : 文章主键
              title : string : 文章标题
              author : number : 作者主键
              authorName : string : 作者名称
              authorImg : string : 作者头像
              essPicUrl : string : 文章封面
              content : string : 文章正文
              status : number : 文章当前状态
    """
    _method = "GET"
    _url = "/content/essay/getById"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 文章主键
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/essay/updateStatus")
def content_essay_updatestatus( headers=None, **kwargs):
    """
    后台管理-内容审核1030-Y
    up_time=1675736685

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/essay/updateStatus"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/essay/getCommentList")
def content_essay_getcommentlist(size=None, parentId=None, keyWord=None, commentId=None, endTime=None, checkedStatus=None, essayId=None, startTime=None, current=None, headers=None, **kwargs):
    """
    后台管理-评论信息1030-Y
    up_time=1675736123

    params: essayId :  : 文章主键
    params: keyWord :  : 关键词
    params: checkedStatus :  : 审核状态 审核状态 0待审核 1.已上架 2.审核未通过3：已下架 5已删除
    params: startTime :  : 开始时间
    params: endTime :  : 结束时间
    params: commentId :  : 评论id
    params: parentId :  : 父级id
    params: size :  : 每页数量
    params: current :  : 当前页
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              ysj : number : 已上架评论数量
              dsh : number : 待审核评论数量
              ysc : number : 已删除评论数量
              yxj : number : 已下架评论数量
              page : object : 
              shbg : number : 审核不过数量
    """
    _method = "GET"
    _url = "/content/essay/getCommentList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 文章主键
        "keyWord": keyWord,  # 关键词
        "checkedStatus": checkedStatus,  # 审核状态 审核状态 0待审核 1.已上架 2.审核未通过3：已下架 5已删除
        "startTime": startTime,  # 开始时间
        "endTime": endTime,  # 结束时间
        "commentId": commentId,  # 评论id
        "parentId": parentId,  # 父级id
        "size": size,  # 每页数量
        "current": current,  # 当前页
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.order.asserts_order_freeorder import AssertsOrderFreeorder
from service.app_a.apis.order import apis_order_freeorder


class FunsOrderFreeorder(AssertsOrderFreeorder):
    @allure.step(title="导出0元订购预定信息表-Y")
    def order_freeorder_download(self, userPolicyCode="$None$", createTime="$None$", regisTimeBegin="$None$", avatarUrl="$None$", userName="$None$", privacyPolicyCode="$None$", regisTimeEnd="$None$", channel="$None$", freeOrderId="$None$", cityId="$None$", mobile="$None$", provinceId="$None$", cityName="$None$", modelId="$None$", channelName="$None$", nickName="$None$", provinceName="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/freeOrder/downLoad
                params: freeOrderId : integer : 订单号
                params: modelId : string : 车型编码
                params: userName : string : 用户姓名
                params: mobile : string : 用户号码
                params: provinceId : string : 省编码
                params: provinceName : string : 省
                params: cityId : string : 市编码
                params: cityName : string : 市
                params: channel : string : 渠道 0 官网 1 app
                params: channelName : string :
                params: createTime : string : 订单创建时间
                params: regisTimeBegin : string : 开始时间
                params: regisTimeEnd : string : 结束时间
                params: nickName : string : 昵称
                params: avatarUrl : string : 头像
                params: userPolicyCode : string : 用户协议版本号
                params: privacyPolicyCode : string : 隐私协议版本号
                params: headers : 请求头
        """
        userPolicyCode = self.get_value_choice(userPolicyCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        createTime = self.get_value_choice(createTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        regisTimeBegin = self.get_value_choice(regisTimeBegin, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        avatarUrl = self.get_value_choice(avatarUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        userName = self.get_value_choice(userName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        privacyPolicyCode = self.get_value_choice(privacyPolicyCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        regisTimeEnd = self.get_value_choice(regisTimeEnd, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        channel = self.get_value_choice(channel, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        freeOrderId = self.get_value_choice(freeOrderId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        cityId = self.get_value_choice(cityId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        mobile = self.get_value_choice(mobile, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        provinceId = self.get_value_choice(provinceId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        cityName = self.get_value_choice(cityName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        modelId = self.get_value_choice(modelId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        channelName = self.get_value_choice(channelName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        nickName = self.get_value_choice(nickName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        provinceName = self.get_value_choice(provinceName, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_freeorder.order_freeorder_download(**_kwargs)

        self.assert_order_freeorder_download(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.goods.asserts_goods_ordermain import AssertsGoodsOrdermain
from service.app_a.apis.goods import apis_goods_ordermain


class FunsGoodsOrdermain(AssertsGoodsOrdermain):
    @allure.step(title="已提车按钮接口-Y")
    def goods_ordermain_pay(self, orderMainId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/goods/orderMain/pay
                params: orderMainId : text : 订单id
                params: headers : 请求头
        """
        orderMainId = self.get_value_choice(orderMainId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_ordermain.goods_ordermain_pay(**_kwargs)

        self.assert_goods_ordermain_pay(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单列表文件导出接口-Y")
    def goods_ordermain_orderexports(self, billStatus="$None$", exportType="$None$", shopName="$None$", userName="$None$", endTime="$None$", testDriveIdStr="$None$", modelName="$None$", userMobile="$None$", startTime="$None$", _assert=True,  **kwargs):
        """
            url=/goods/orderMain/orderExports
                params: userMobile :  : 手机号
                params: userName :  : 用户名
                params: shopName :  : 店名
                params: modelName :  : 车型
                params: billStatus	 :  : 支付状态
                params: startTime :  : 开始时间
                params: endTime :  : 结束时间
                params: exportType :  : 导出类型
                params: testDriveIdStr :  : 订单集合字符串
                params: headers : 请求头
        """
        billStatus = self.get_list_choice(billStatus, list_or_dict=None, key="billStatus")
        exportType = self.get_list_choice(exportType, list_or_dict=None, key="exportType")
        shopName = self.get_list_choice(shopName, list_or_dict=None, key="shopName")
        userName = self.get_list_choice(userName, list_or_dict=None, key="userName")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        testDriveIdStr = self.get_list_choice(testDriveIdStr, list_or_dict=None, key="testDriveIdStr")
        modelName = self.get_list_choice(modelName, list_or_dict=None, key="modelName")
        userMobile = self.get_list_choice(userMobile, list_or_dict=None, key="userMobile")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_ordermain.goods_ordermain_orderexports(**_kwargs)

        self.assert_goods_ordermain_orderexports(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单查询接口-Y")
    def goods_ordermain_getordermainpage(self, shopName="$None$", userName="$None$", orderStatus="$None$", endTime="$None$", modelName="$None$", userMobile="$None$", startTime="$None$", _assert=True,  **kwargs):
        """
            url=/goods/orderMain/getOrderMainPage
                params: userMobile :  : 手机号
                params: userName :  : 用户名
                params: modelName :  : 车型
                params: orderStatus	 :  : 支付状态 1001待支付 1002已支付 1003已完成 1004待退款
                1005已取消 1006已退款 1007已驳回
                params: startTime :  : 开始时间
                params: endTime :  : 结束时间
                params: shopName :  : 门店名称
                params: headers : 请求头
        """
        shopName = self.get_list_choice(shopName, list_or_dict=None, key="shopName")
        userName = self.get_list_choice(userName, list_or_dict=None, key="userName")
        orderStatus = self.get_list_choice(orderStatus, list_or_dict=None, key="orderStatus")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        modelName = self.get_list_choice(modelName, list_or_dict=None, key="modelName")
        userMobile = self.get_list_choice(userMobile, list_or_dict=None, key="userMobile")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_ordermain.goods_ordermain_getordermainpage(**_kwargs)

        self.assert_goods_ordermain_getordermainpage(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单详情查询-Y")
    def goods_ordermain_getordermainbyid(self, orderMainId="$None$", _assert=True,  **kwargs):
        """
            url=/goods/orderMain/getOrderMainById
                params: orderMainId :  : 订单id
                params: headers : 请求头
        """
        orderMainId = self.get_list_choice(orderMainId, list_or_dict=None, key="orderMainId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_ordermain.goods_ordermain_getordermainbyid(**_kwargs)

        self.assert_goods_ordermain_getordermainbyid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/essayweb/add")
def content_essayweb_add(publishChannel=None, essPicUrl=None, publishType=None, author=None, essayId=None, title=None, content=None, status=None, publishTime=None, headers=None, **kwargs):
    """
    专题-后台官网专题新建文章-Y
    up_time=1675737086

    params: essayId : string : 文章主键
    params: title : string : 文章标题
    params: author : string : 作者
    params: publishType : string : 发布类型1：立即发布2：定时发布
    params: publishTime : string : 定时发布时间
    params: essPicUrl : string : 文章封面
    params: publishChannel : string : 发布渠道
    params: content : string : 文章正文富文本
    params: status : string : 保存时传1，提交审核时传2
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/essayweb/add"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 文章主键
        "title": title,  # 文章标题
        "author": author,  # 作者
        "publishType": publishType,  # 发布类型1：立即发布2：定时发布
        "publishTime": publishTime,  # 定时发布时间
        "essPicUrl": essPicUrl,  # 文章封面
        "publishChannel": publishChannel,  # 发布渠道
        "content": content,  # 文章正文富文本
        "status": status,  # 保存时传1，提交审核时传2
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/essayweb/searchByKey")
def content_essayweb_searchbykey(key=None, size=None, current=None, headers=None, **kwargs):
    """
    专题-后台官网文章关键词搜索-Y
    up_time=1675737282

    params: current :  : 当前页
    params: size :  : 每页条数
    params: key :  : 关键词
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/content/essayweb/searchByKey"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,  # 当前页
        "size": size,  # 每页条数
        "key": key,  # 关键词
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/essayweb/delete/")
def content_essayweb_delete_(essayId=None, headers=None, **kwargs):
    """
    专题-后台官网文章删除-Y
    up_time=1675737243

    params: essayId :  : 文章id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0 成功 1失败 
    params: msg : string : 
    params: data : null : 
    """
    _method = "POST"
    _url = "/content/essayweb/delete/{essayId}"
    _url = get_url(_url, locals())

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
        "essayId": essayId,  # 文章id
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/essayweb/getById")
def content_essayweb_getbyid(subjectId=None, essayId=None, headers=None, **kwargs):
    """
    新闻中心查看文章详情-Y
    up_time=1675737040

    params: essayId :  : 文章主键
    params: subjectId :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              code : number : 
              msg : string : 
              data : object : 
    """
    _method = "GET"
    _url = "/content/essayweb/getById"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 文章主键
        "subjectId": subjectId,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.content.asserts_content_agreement import AssertsContentAgreement
from service.app_a.apis.content import apis_content_agreement


class FunsContentAgreement(AssertsContentAgreement):
    @allure.step(title="查询创建活动所需协议")
    def content_agreement_getagreement(self, _assert=True,  **kwargs):
        """
            url=/content/agreement/getAgreement
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_agreement.content_agreement_getagreement(**_kwargs)

        self.assert_content_agreement_getagreement(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="协议-C端用户根据编码查询协议-Y")
    def content_agreement_getbycode(self, agreementCode="$None$", _assert=True,  **kwargs):
        """
            url=/content/agreement/getByCode
                params: agreementCode :  : PRIVACYPOLICY:隐私协议，USERPOLICY：用户协议， THIRDPARTYSDKPOLICY：第三方sdk目录，POINTRULE：积分规则，SIGININRULE：签到规则
                params: headers : 请求头
        """
        agreementCode = self.get_list_choice(agreementCode, list_or_dict=None, key="agreementCode")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_agreement.content_agreement_getbycode(**_kwargs)

        self.assert_content_agreement_getbycode(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="协议-h5查询协议-Y")
    def content_agreement_getagreementbycode(self, agreementCode="$None$", _assert=True,  **kwargs):
        """
            url=/content/agreement/getAgreementByCode
                params: agreementCode :  : 协议编码
                隐私协议:PRIVACYPOLICY、
                用户协议:USERPOLICY、
                权限清单:PERMISSIONSLIST、
                第三方SDK列表:THIRDPARTYSDKPOLICY、
                用户注销: USERDESTROY
                车机服务协议: CARSERVICE
                params: headers : 请求头
        """
        agreementCode = self.get_list_choice(agreementCode, list_or_dict=None, key="agreementCode")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_agreement.content_agreement_getagreementbycode(**_kwargs)

        self.assert_content_agreement_getagreementbycode(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="协议-停用启用协议-Y")
    def content_agreement_updatestatus(self, code="$None$", agreementId="$None$", status="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/agreement/updateStatus
                params: agreementId : text :
                params: status : text : 状态 1 启用 2 停用
                params: code : text : 协议编码
                params: headers : 请求头
        """
        code = self.get_value_choice(code, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        agreementId = self.get_value_choice(agreementId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_agreement.content_agreement_updatestatus(**_kwargs)

        self.assert_content_agreement_updatestatus(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="协议-协议列表-Y")
    def content_agreement_list(self, size=10, current=1, _assert=True,  **kwargs):
        """
            url=/content/agreement/list
                params: size :  : 每页数据数
                params: current :  : 当前页
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_agreement.content_agreement_list(**_kwargs)

        self.assert_content_agreement_list(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="协议-新增协议-Y")
    def content_agreement_save(self, code="$None$", content="$None$", name="$None$", version="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/agreement/save
                params: name : string : 协议名
                params: content : string : 内容
                params: version : number : 版本号
                params: code : string : 协议编码
                params: headers : 请求头
        """
        code = self.get_value_choice(code, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        content = self.get_value_choice(content, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        name = self.get_value_choice(name, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        version = self.get_value_choice(version, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_agreement.content_agreement_save(**_kwargs)

        self.assert_content_agreement_save(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="协议-更新协议-Y")
    def content_agreement_update(self, code="$None$", name="$None$", agreementId="$None$", version="$None$", content="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/agreement/update
                params: name : string : 协议名
                params: content : string : 内容
                params: version : number : 版本号
                params: agreementId : string : 协议id
                params: code : string : 协议编码
                params: headers : 请求头
        """
        code = self.get_value_choice(code, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        name = self.get_value_choice(name, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        agreementId = self.get_value_choice(agreementId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        version = self.get_value_choice(version, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        content = self.get_value_choice(content, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_agreement.content_agreement_update(**_kwargs)

        self.assert_content_agreement_update(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="协议-根据id获取详情-Y")
    def content_agreement_getbyid(self, agreementId="$None$", _assert=True,  **kwargs):
        """
            url=/content/agreement/getById
                params: agreementId :  : 协议主键1-隐私协议2-用户协议3-第三方SDK目录
                params: headers : 请求头
        """
        agreementId = self.get_list_choice(agreementId, list_or_dict=None, key="agreementId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_agreement.content_agreement_getbyid(**_kwargs)

        self.assert_content_agreement_getbyid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/common/clue/getClueUserPage")
def common_clue_getclueuserpage(userId=None, size=None, current=None, headers=None, **kwargs):
    """
    用户列表-详情-查询线索-Y
    up_time=1675318572

    params: current :  : 页码
    params: size :  : 每页大小
    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : string : 
              maxLimit : number : 
              pages : number : 
              field_66 : string : 
    """
    _method = "GET"
    _url = "/common/clue/getClueUserPage"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,  # 页码
        "size": size,  # 每页大小
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.radarpoints.sqls_radarpoints_userpoints import SqlsRadarpointsUserpoints


class AssertsRadarpointsUserpoints(SqlsRadarpointsUserpoints):
    @allure.step(title="接口返回结果校验")
    def assert_radarpoints_userpoints_pagelist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_radarpoints_userpoints_pagelist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["cumulativeConsumptionMost", "userId", "physicalIntegralLeast", "registrationTimeEnd", "freezeQtyLeast", "registrationTimeBegin", "cumulativeAcquisitionMost", "mobile", "cumulativeAcquisitionLeast", "cumulativeConsumptionLeast", "freezeQtyMost", "physicalIntegralMost", "nickName", "conversionFrequencyLeast", "conversionFrequencyMost"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_radarpoints_userpoints_export(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_radarpoints_userpoints_export(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["cumulativeConsumptionMost", "physicalIntegralLeast", "registrationTimeEnd", "registrationTimeBegin", "cumulativeAcquisitionMost", "cumulativeAcquisitionLeast", "cumulativeConsumptionLeast", "physicalIntegralMost", "nickName", "conversionFrequencyLeast", "conversionFrequencyMost"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/goods/orderMain/pay")
def goods_ordermain_pay(orderMainId=None, headers=None, **kwargs):
    """
    已提车按钮接口-Y
    up_time=1675328427

    params: orderMainId : text : 订单id
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/goods/orderMain/pay"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "orderMainId": orderMainId,  # 订单id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/orderMain/orderExports")
def goods_ordermain_orderexports(billStatus	=None, exportType=None, shopName=None, userName=None, endTime=None, testDriveIdStr=None, modelName=None, userMobile=None, startTime=None, headers=None, **kwargs):
    """
    订单列表文件导出接口-Y
    up_time=1675660544

    params: userMobile :  : 手机号
    params: userName :  : 用户名
    params: shopName :  : 店名
    params: modelName :  : 车型
    params: billStatus	 :  : 支付状态
    params: startTime :  : 开始时间
    params: endTime :  : 结束时间
    params: exportType :  : 导出类型
    params: testDriveIdStr :  : 订单集合字符串
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/goods/orderMain/orderExports"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userMobile": userMobile,  # 手机号
        "userName": userName,  # 用户名
        "shopName": shopName,  # 店名
        "modelName": modelName,  # 车型
        "billStatus	": billStatus	,  # 支付状态
        "startTime": startTime,  # 开始时间
        "endTime": endTime,  # 结束时间
        "exportType": exportType,  # 导出类型
        "testDriveIdStr": testDriveIdStr,  # 订单集合字符串
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/orderMain/getOrderMainPage")
def goods_ordermain_getordermainpage(shopName=None, userName=None, orderStatus	=None, endTime=None, modelName=None, userMobile=None, startTime=None, headers=None, **kwargs):
    """
    订单查询接口-Y
    up_time=1675660564

    params: userMobile :  : 手机号
    params: userName :  : 用户名
    params: modelName :  : 车型
    params: orderStatus	 :  : 支付状态 1001待支付 1002已支付 1003已完成 1004待退款
1005已取消 1006已退款 1007已驳回
    params: startTime :  : 开始时间
    params: endTime :  : 结束时间
    params: shopName :  : 门店名称
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功
    params: msg : string : 描述
    params: data : object : 返回
              records : array : 小订订单集合
              maxLimit : number : 待退款角标
              total : number : 总行数
              size : number : 每页数
              current : number : 当前页
              pages : number : 
    """
    _method = "GET"
    _url = "/goods/orderMain/getOrderMainPage"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userMobile": userMobile,  # 手机号
        "userName": userName,  # 用户名
        "modelName": modelName,  # 车型
        "orderStatus	": orderStatus	,  # 支付状态 1001待支付 1002已支付 1003已完成 1004待退款 1005已取消 1006已退款 1007已驳回
        "startTime": startTime,  # 开始时间
        "endTime": endTime,  # 结束时间
        "shopName": shopName,  # 门店名称
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/orderMain/getOrderMainById")
def goods_ordermain_getordermainbyid(orderMainId=None, headers=None, **kwargs):
    """
    订单详情查询-Y
    up_time=1675660571

    params: orderMainId :  : 订单id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              orderMainId : number : 订单id
              channelId : number : 渠道id
              orderType : string : 订单类型
              userId : number : 用户id
              userName : string : 用户名
              userMobile : string : 手机号
              createTime : string : 创建时间
              customerName : null : 客户名
              userType : null : 用户类型
              phone : null : 客户手机号
              areaName : string : 上牌城市
              shopId : number : 网点id
              shopName : string : 网点名称
              shopAddress : string : 网点地址
              modelId : number : 车型id
              modelName : string : 车型名称
              configurationAndOptions : string : 选装与配置
              totalPrice : number : 购车总价
              prePrice : number : 定金
              payType : number : 支付方式1：微信支付 2:支付宝支付
              payTime : string : 支付时间
              billStatus : number : 单据状态0：待支付 1：支付成功 2：支付失败
              avatar : null : 头像
    """
    _method = "GET"
    _url = "/goods/orderMain/getOrderMainById"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "orderMainId": orderMainId,  # 订单id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





from service.app_a.apis.radarpoints import apis_radarpoints_userpoints
from service.app_a.asserts.radarpoints.asserts_radarpoints_userpoints import AssertsRadarpointsUserpoints
import allure
from service.app_a.funs.radarpoints.userpoints.funs_radarpoints_userpoints_pointsinfo import FunsRadarpointsUserpointsPointsinfo
from service.app_a.funs.radarpoints.userpoints.funs_radarpoints_userpoints_exchangeinfo import FunsRadarpointsUserpointsExchangeinfo


class FunsRadarpointsUserpoints(FunsRadarpointsUserpointsPointsinfo, FunsRadarpointsUserpointsExchangeinfo, AssertsRadarpointsUserpoints):
    @allure.step(title="用户积分 - 分页查询")
    def radarpoints_userpoints_pagelist(self, cumulativeConsumptionMost="$None$", userId="$None$", physicalIntegralLeast="$None$", registrationTimeEnd="$None$", freezeQtyLeast="$None$", current=1, registrationTimeBegin="$None$", size=10, cumulativeAcquisitionMost="$None$", mobile="$None$", cumulativeAcquisitionLeast="$None$", cumulativeConsumptionLeast="$None$", freezeQtyMost="$None$", physicalIntegralMost="$None$", nickName="$None$", conversionFrequencyLeast="$None$", conversionFrequencyMost="$None$", _assert=True,  **kwargs):
        """
            url=/radarpoints/userPoints/pageList
                params: mobile :  : 用户手机号
                params: nickName :  : 用户昵称
                params: registrationTimeBegin :  : 注册时间 - 开始
                params: registrationTimeEnd :  : 注册时间 - 结束
                params: physicalIntegralLeast :  : 持有积分 - 最少
                params: physicalIntegralMost :  : 持有积分 - 最多
                params: cumulativeAcquisitionLeast :  : 累计获取 - 最少
                params: cumulativeAcquisitionMost :  : 累计获取 - 最多
                params: cumulativeConsumptionLeast :  : 累计消耗 - 最少
                params: cumulativeConsumptionMost :  : 累计消耗 - 最多
                params: conversionFrequencyLeast :  : 兑换次数 - 最少
                params: conversionFrequencyMost :  : 兑换次数 - 最多
                params: freezeQtyLeast :  : 冻结积分 - 最少
                params: freezeQtyMost :  : 冻结积分 - 最多
                params: current :  : 页码
                params: size :  : 每页大小
                params: headers : 请求头
        """
        cumulativeConsumptionMost = self.get_list_choice(cumulativeConsumptionMost, list_or_dict=None, key="cumulativeConsumptionMost")
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        physicalIntegralLeast = self.get_list_choice(physicalIntegralLeast, list_or_dict=None, key="physicalIntegralLeast")
        registrationTimeEnd = self.get_list_choice(registrationTimeEnd, list_or_dict=None, key="registrationTimeEnd")
        freezeQtyLeast = self.get_list_choice(freezeQtyLeast, list_or_dict=None, key="freezeQtyLeast")
        registrationTimeBegin = self.get_list_choice(registrationTimeBegin, list_or_dict=None, key="registrationTimeBegin")
        cumulativeAcquisitionMost = self.get_list_choice(cumulativeAcquisitionMost, list_or_dict=None, key="cumulativeAcquisitionMost")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        cumulativeAcquisitionLeast = self.get_list_choice(cumulativeAcquisitionLeast, list_or_dict=None, key="cumulativeAcquisitionLeast")
        cumulativeConsumptionLeast = self.get_list_choice(cumulativeConsumptionLeast, list_or_dict=None, key="cumulativeConsumptionLeast")
        freezeQtyMost = self.get_list_choice(freezeQtyMost, list_or_dict=None, key="freezeQtyMost")
        physicalIntegralMost = self.get_list_choice(physicalIntegralMost, list_or_dict=None, key="physicalIntegralMost")
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")
        conversionFrequencyLeast = self.get_list_choice(conversionFrequencyLeast, list_or_dict=None, key="conversionFrequencyLeast")
        conversionFrequencyMost = self.get_list_choice(conversionFrequencyMost, list_or_dict=None, key="conversionFrequencyMost")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_userpoints.radarpoints_userpoints_pagelist(**_kwargs)

        self.assert_radarpoints_userpoints_pagelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户积分 - 导出excel")
    def radarpoints_userpoints_export(self, cumulativeConsumptionMost="$None$", physicalIntegralLeast="$None$", registrationTimeEnd="$None$", currentPage="$None$", registrationTimeBegin="$None$", cumulativeAcquisitionMost="$None$", pageSize="$None$", cumulativeAcquisitionLeast="$None$", cumulativeConsumptionLeast="$None$", physicalIntegralMost="$None$", nickName="$None$", conversionFrequencyLeast="$None$", conversionFrequencyMost="$None$", _assert=True,  **kwargs):
        """
            url=/radarpoints/userPoints/export
                params: nickName :  : 用户昵称
                params: registrationTimeBegin :  : 注册时间 - 开始
                params: registrationTimeEnd :  : 注册时间 - 结束
                params: physicalIntegralLeast :  : 持有积分 - 最少
                params: physicalIntegralMost :  : 持有积分 - 最多
                params: cumulativeAcquisitionLeast :  : 累计获取 - 最少
                params: cumulativeAcquisitionMost :  : 累计获取 - 最多
                params: cumulativeConsumptionLeast :  : 累计消耗 - 最少
                params: cumulativeConsumptionMost :  : 累计消耗 - 最多
                params: conversionFrequencyLeast :  : 兑换次数 - 最少
                params: conversionFrequencyMost :  : 兑换次数 - 最多
                params: currentPage :  : 当前页码
                params: pageSize :  : 每页大小
                params: headers : 请求头
        """
        cumulativeConsumptionMost = self.get_list_choice(cumulativeConsumptionMost, list_or_dict=None, key="cumulativeConsumptionMost")
        physicalIntegralLeast = self.get_list_choice(physicalIntegralLeast, list_or_dict=None, key="physicalIntegralLeast")
        registrationTimeEnd = self.get_list_choice(registrationTimeEnd, list_or_dict=None, key="registrationTimeEnd")
        currentPage = self.get_list_choice(currentPage, list_or_dict=None, key="currentPage")
        registrationTimeBegin = self.get_list_choice(registrationTimeBegin, list_or_dict=None, key="registrationTimeBegin")
        cumulativeAcquisitionMost = self.get_list_choice(cumulativeAcquisitionMost, list_or_dict=None, key="cumulativeAcquisitionMost")
        pageSize = self.get_list_choice(pageSize, list_or_dict=None, key="pageSize")
        cumulativeAcquisitionLeast = self.get_list_choice(cumulativeAcquisitionLeast, list_or_dict=None, key="cumulativeAcquisitionLeast")
        cumulativeConsumptionLeast = self.get_list_choice(cumulativeConsumptionLeast, list_or_dict=None, key="cumulativeConsumptionLeast")
        physicalIntegralMost = self.get_list_choice(physicalIntegralMost, list_or_dict=None, key="physicalIntegralMost")
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")
        conversionFrequencyLeast = self.get_list_choice(conversionFrequencyLeast, list_or_dict=None, key="conversionFrequencyLeast")
        conversionFrequencyMost = self.get_list_choice(conversionFrequencyMost, list_or_dict=None, key="conversionFrequencyMost")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_userpoints.radarpoints_userpoints_export(**_kwargs)

        self.assert_radarpoints_userpoints_export(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





from service.app_a.funs.common.funs_common_systemversion import FunsCommonSystemversion
from service.app_a.funs.common.funs_common_remoteinterfacelog import FunsCommonRemoteinterfacelog
from service.app_a.funs.common.funs_common_user4c import FunsCommonUser4C
from service.app_a.funs.common.funs_common_clue import FunsCommonClue
from service.app_a.funs.common.funs_common_user import FunsCommonUser
from service.app_a.funs.common.funs_common_common import FunsCommonCommon
from service.app_a.funs.common.funs_common_userpointsmanage import FunsCommonUserpointsmanage


class FunsCommon(FunsCommonSystemversion, FunsCommonRemoteinterfacelog, FunsCommonUser4C, FunsCommonClue, FunsCommonUser, FunsCommonCommon, FunsCommonUserpointsmanage):
    pass




import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/order/mainOrder/pageList")
def order_mainorder_pagelist(createEndTime=None, size=None, sortItems=None, createStartTime=None, current=None, headers=None, **kwargs):
    """
    小订订单分页查询（后台）-Y
    up_time=1683860159

    params: current : string : 
    params: size : string : 
    params: sortItems : string : 排序字段（只能是【orderMain.orderType】、【orderMain.createTime】、【orderPay.createTime】）
    params: createStartTime : string : 订单创建开始日期
    params: createEndTime : string : 订单创建结束日期
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0.成功 1.失败	
    params: msg : string : 
    params: data : object : 
              total : number : 
              list : array : 订单列表
              pageNum : number : 
              pageSize : number : 
              size : number : 
              startRow : number : 
              endRow : number : 
              pages : number : 
              prePage : number : 
              nextPage : number : 
              isFirstPage : boolean : 
              isLastPage : boolean : 
              hasPreviousPage : boolean : 
              hasNextPage : boolean : 
              navigatePages : number : 
              navigatepageNums : null : 
              navigateFirstPage : number : 
              navigateLastPage : number : 
    """
    _method = "POST"
    _url = "/order/mainOrder/pageList"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,
        "size": size,
        "sortItems": sortItems,  # 排序字段（只能是【orderMain.orderType】、【orderMain.createTime】、【orderPay.createTime】）
        "createStartTime": createStartTime,  # 订单创建开始日期
        "createEndTime": createEndTime,  # 订单创建结束日期
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)



@allure.step(title="调接口：/order/mainOrder/downLoad")
def order_mainorder_download(createEndTime=None, orderTypeToSort=None, createTimeToSort=None, payTimeToSort=None, createStartTime=None, headers=None, **kwargs):
    """
    小订订单列表导出（后台）-Y
    up_time=1675326837

    params: orderTypeToSort : string : 订单类型排序 不排序不赋值 正序：asc 倒序：desc
    params: createTimeToSort : string : 订单创建时间 不排序不赋值 正序：asc 倒序：desc
    params: payTimeToSort : string : 订单创建时间 不排序不赋值 正序：asc 倒序：desc
    params: createStartTime : string : 订单创建开始日期
    params: createEndTime : string : 订单创建结束日期
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/order/mainOrder/downLoad"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "orderTypeToSort": orderTypeToSort,  # 订单类型排序 不排序不赋值 正序：asc 倒序：desc
        "createTimeToSort": createTimeToSort,  # 订单创建时间 不排序不赋值 正序：asc 倒序：desc
        "payTimeToSort": payTimeToSort,  # 订单创建时间 不排序不赋值 正序：asc 倒序：desc
        "createStartTime": createStartTime,  # 订单创建开始日期
        "createEndTime": createEndTime,  # 订单创建结束日期
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/mainOrder/detail")
def order_mainorder_detail(orderId=None, headers=None, **kwargs):
    """
    小订订单查询订单详情（后台）-Y
    up_time=1675328256

    params: orderId :  : 订单号
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0.成功 1.失败		
    params: msg : string : 
    params: data : object : 
              orderTypeToSort : null : 
              createTimeToSort : null : 
              payTimeToSort : null : 
              createStartTime : null : 
              createEndTime : null : 
              userId : null : 
              orderId : string : 订单号
              orderStatus : string : 订单状态
              orderStatusName : string : 订单状态名称
              createTime : string : 订单创建时间
              userName : string : 购买人
              mobile : string : 购买人手机号
              prePrice : string : 定金
              totalPrice : string : 总价
              model : null : 
              battery : null : 
              itemList : null : 
              modelPic : null : 
              interiorPic : null : 
              shopVo : null : 
              areaName : null : 
              provinceId : string : 省编码
              cityId : string : 城市编码
              orderType : string : 订单类型
              orderTypeName : null : 订单类型名称
              modelId : string : 车型ID
              existFreeOrder : string : 用户是否存在零元购：0 不存在 1 存在
              existFreeOrderName : string : 用户是否存在零元购名称
              pageSize : number : 
              pageNum : number : 
              total : number : 
              goodsTotal : number : 
              orderProcess : array : 订单链路
              prePricePosterImageUrl : string : 预订金海报图片地址
              modelName : string : 车型名称
              prePriceContent : string : 预订权益内容
              freePriceContent : string : 零元购权益内容
    """
    _method = "GET"
    _url = "/order/mainOrder/detail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "orderId": orderId,  # 订单号
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/mainOrder/getUserOrderStatusList")
def order_mainorder_getuserorderstatuslist( headers=None, **kwargs):
    """
    订单管理-查询所有用户订单状态-Y
    up_time=1675320292

    params: headers : 请求头
    ====================返回======================
    params: code : integer : 0.成功 1.失败
    params: msg : string : 
    params: data : array : 
              userOrderStatus : string : 用户展示的订单状态
              userOrderStatusName : string : 用户展示的订单状态名称
              sort : integer : 排序
    """
    _method = "GET"
    _url = "/order/mainOrder/getUserOrderStatusList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/mainOrder/getOrderTypeList")
def order_mainorder_getordertypelist( headers=None, **kwargs):
    """
    订单管理-后台查询所有订单类型-Y
    up_time=1675320267

    params: headers : 请求头
    ====================返回======================
    params: code : integer : 0.成功 1.失败
    params: msg : string : 
    params: data : array : 
              orderType : string : 订单类型
              orderTypeName : string : 订单类型名称
              orderTypeProgramLanguage : string : 订单类型程序语言
    """
    _method = "GET"
    _url = "/order/mainOrder/getOrderTypeList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/mainOrder/getExtOrderStatusList")
def order_mainorder_getextorderstatuslist( headers=None, **kwargs):
    """
    订单管理-后台查询所有销售单订单状态-Y
    up_time=1675320328

    params: headers : 请求头
    ====================返回======================
    params: code : integer : 0.成功 1.失败
    params: msg : string : 
    params: data : array : 
              extOrderStatus : string : 第三方订单状态
              extOrderStatusName : string : 第三方订单状态名称
              userOrderStatus : string : 用户展示的订单状态
              userOrderStatusName : string : 用户展示的订单状态名称
              sort : integer : 排序
              showFlag : integer : 下拉框是否显示标识：0不显示，1显示
    """
    _method = "GET"
    _url = "/order/mainOrder/getExtOrderStatusList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/mainOrder/getOrderStatusList")
def order_mainorder_getorderstatuslist( headers=None, **kwargs):
    """
    订单管理-查询所有订单状态-Y
    up_time=1675319495

    params: headers : 请求头
    ====================返回======================
    params: code : number : 0.成功 1.失败
    params: msg : string : 
    params: data : array : 
              orderStatus : string : 订单状态
              orderStatusName : string : 订单状态名称
    """
    _method = "GET"
    _url = "/order/mainOrder/getOrderStatusList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/mainOrder/vinCode")
def order_mainorder_vincode(vin=None, headers=None, **kwargs):
    """
    订单管理-通过vin码查询订单-Y
    up_time=1676969860

    params: vin :  : 车辆唯一vin码
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 0.成功 1.失败
    params: msg : string : 
    params: data : object : 
              vin : string : vin 码
              bandCode : string : 品牌 code
              bandName : string : 品牌 名称
              seriesCode : string : 车系 code
              seriesName : string : 车系 名称
              modelCode : string : 车型code
              modelName : string : 车型名称
              pno18Array : string : PNO18码
              configureCode : string : 配置code
              configureCodeName : string : 配置名称
              interiorCode : string : 内饰code
              interiorCodeName : string : 内饰code
              optionalCodeList : array : 选装code集合
              supportDischarge : integer : 是否支持放电
              supportBluetooth : integer : 是否支持蓝牙
              supportSendToCar : integer : 是否支持发送到车
    """
    _method = "GET"
    _url = "/order/mainOrder/vinCode"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "vin": vin,  # 车辆唯一vin码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/mainOrder/finish")
def order_mainorder_finish(orderId=None, headers=None, **kwargs):
    """
    订单管理-订单完成-Y
    up_time=1675660618

    params: orderId : string : 
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 0失败1成功
    params: msg : string : 
    params: data : object : 
    """
    _method = "POST"
    _url = "/order/mainOrder/finish"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "orderId": orderId,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/mainOrder/allPriceContent")
def order_mainorder_allpricecontent(orderId=None, headers=None, **kwargs):
    """
    订单管理-查询订单权益接口-Y
    up_time=1675660625

    params: orderId :  : 子订单号 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              userName : string : 联系人姓名
              userMobile : string : 联系人手机号
              orderName : string : 用户昵称,
              orderMobile : string : 用户号码
              allPriceContent : string : 权益内容
    """
    _method = "GET"
    _url = "/order/mainOrder/allPriceContent"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "orderId": orderId,  # 子订单号 
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/mainOrder/getOrderIdByUser")
def order_mainorder_getorderidbyuser(userId=None, headers=None, **kwargs):
    """
    订单管理-通过用户ID查询订单ID-Y
    up_time=1675660638

    params: userId :  : 用户id
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/order/mainOrder/getOrderIdByUser"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/mainOrder/=getModelNameByOrderId")
def order_mainorder__getmodelnamebyorderid(orderId=None, headers=None, **kwargs):
    """
    订单管理-通过订单号获取车型名称-Y
    up_time=1675660646

    params: orderId :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
    """
    _method = "GET"
    _url = "/order/mainOrder/=getModelNameByOrderId"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "orderId": orderId,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/mainOrder/getCarConfigByOrderId")
def order_mainorder_getcarconfigbyorderid(orderId=None, headers=None, **kwargs):
    """
    订单管理-通过订单号获取配置信息-Y
    up_time=1675660654

    params: orderId :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              salesVersion : string : 销售版本
              appearanceColor : string : 外观颜色
              processColor : string : 套色
              interiorColor : string : 内饰颜色
    """
    _method = "GET"
    _url = "/order/mainOrder/getCarConfigByOrderId"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "orderId": orderId,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/mainOrder/syncScrmExtOrder")
def order_mainorder_syncscrmextorder(VIN=None, deliveryData=None, phone=None, ossId=None, potentialName=None, optionCode=None, orderId=None, updateTime=None, orderAllAmount=None, syncMsg=None, modelCode=None, isArrived=None, orderNo=None, unitInvoiceTitle=None, isTestDrive=None, scUname=None, syncStatus=None, customerCtCode=None, dealerCode=None, seriesCode=None, colorCode=None, trimCode=None, custCertNo=None, isLifetimeWarranty=None, createTime=None, lifetimeWarrantyPrice=None, customerId=None, customerType=None, soNo=None, unitTaxNo=None, soStatus=None, chargePointEquity=None, unitName=None, configCode=None, scUid=None, headers=None, **kwargs):
    """
    SCRM第三方订单同步信息-Y
    up_time=1675406887

    params: ossId : string : 主键
    params: dealerCode : string : 经销商代码
    params: customerId : number : 潜客 ID
    params: isArrived : string : 是否到店（true or false）
    params: isTestDrive : string : 是否试乘试驾（true or false）
    params: orderNo : string : 预订单单号
    params: orderId : number : 预订单订单 ID
    params: soNo : string : DMS 订单编号
    params: soStatus : string : 订单状态
    params: scUid : string : 销售顾问 ID
    params: scUname : string : 销售顾问姓名
    params: VIN : string : 车架号
    params: deliveryData : string : 承诺交车日期
    params: seriesCode : string : 车系代码
    params: modelCode : string : 车型代码
    params: configCode : string : 配置代码
    params: colorCode : string : 外观代码
    params: trimCode : string : 内饰代码
    params: optionCode : string : 选装包
    params: orderAllAmount : number : 订单价格(保留 3 位小数)
    params: customerType : string : 同步个人和企业
    params: potentialName : string : DMS 订单客户手机号
    params: phone : integer : DMS 订单客户证件类型
    params: customerCtCode : string : 证件号码
    params: custCertNo : string : 企业发票抬头
    params: unitName : string : 企业名称
    params: unitInvoiceTitle : string : 企业发票抬头
    params: unitTaxNo : integer : 企业税号
    params: chargePointEquity : integer : 充电桩权益      * 30471001: 7KW 充电桩      * 30471002: 11KW 充电桩      * 30471003: 家充桩置换公充权益      * 30471004:无电车权益
    params: isLifetimeWarranty : integer : (10041001 是, 10041002 否)
    params: lifetimeWarrantyPrice : string : 终身质保价格(保留 2 位小数)
    params: createTime : string : 创建订单时间
    params: updateTime : string : 更新订单时间
    params: syncStatus : integer : 0待同步，1同步成功，2同步失败
    params: syncMsg : string : 同步结果
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0失败1成功
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/order/mainOrder/syncScrmExtOrder"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "ossId": ossId,  # 主键
        "dealerCode": dealerCode,  # 经销商代码
        "customerId": customerId,  # 潜客 ID
        "isArrived": isArrived,  # 是否到店（true or false）
        "isTestDrive": isTestDrive,  # 是否试乘试驾（true or false）
        "orderNo": orderNo,  # 预订单单号
        "orderId": orderId,  # 预订单订单 ID
        "soNo": soNo,  # DMS 订单编号
        "soStatus": soStatus,  # 订单状态
        "scUid": scUid,  # 销售顾问 ID
        "scUname": scUname,  # 销售顾问姓名
        "VIN": VIN,  # 车架号
        "deliveryData": deliveryData,  # 承诺交车日期
        "seriesCode": seriesCode,  # 车系代码
        "modelCode": modelCode,  # 车型代码
        "configCode": configCode,  # 配置代码
        "colorCode": colorCode,  # 外观代码
        "trimCode": trimCode,  # 内饰代码
        "optionCode": optionCode,  # 选装包
        "orderAllAmount": orderAllAmount,  # 订单价格(保留 3 位小数)
        "customerType": customerType,  # 同步个人和企业
        "potentialName": potentialName,  # DMS 订单客户手机号
        "phone": phone,  # DMS 订单客户证件类型
        "customerCtCode": customerCtCode,  # 证件号码
        "custCertNo": custCertNo,  # 企业发票抬头
        "unitName": unitName,  # 企业名称
        "unitInvoiceTitle": unitInvoiceTitle,  # 企业发票抬头
        "unitTaxNo": unitTaxNo,  # 企业税号
        "chargePointEquity": chargePointEquity,  # 充电桩权益      * 30471001: 7KW 充电桩      * 30471002: 11KW 充电桩      * 30471003: 家充桩置换公充权益      * 30471004:无电车权益
        "isLifetimeWarranty": isLifetimeWarranty,  # (10041001 是, 10041002 否)
        "lifetimeWarrantyPrice": lifetimeWarrantyPrice,  # 终身质保价格(保留 2 位小数)
        "createTime": createTime,  # 创建订单时间
        "updateTime": updateTime,  # 更新订单时间
        "syncStatus": syncStatus,  # 0待同步，1同步成功，2同步失败
        "syncMsg": syncMsg,  # 同步结果
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/mainOrder/informOrder")
def order_mainorder_informorder(systemCode=None, sourceInfo=None, headers=None, **kwargs):
    """
     SCRM第三方转派经销商通知APP同步日志-Y
    up_time=1675407343

    params: sourceInfo : array : 批量操作
              orderId : string : 订单ID
              customerId : number : 潜客ID
              dealerCode : string : 经销商代码(变更后的经销商)
              orderNo : number : 预订单单号
              soNo : string : DMS订单编号
              soStatus : string : 订单状态
              scUid : string : 销售顾问ID
              scUname : string : 销售顾问姓名
    params: systemCode : string : 变更系统
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 0失败1成功
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/order/mainOrder/informOrder"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "sourceInfo": sourceInfo,  # 批量操作
        "systemCode": systemCode,  # 变更系统
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/safeCode/close")
def content_safecode_close(safeCode=None, headers=None, **kwargs):
    """
    安全码关闭-Y
    up_time=1675748298

    params: safeCode : string : 安全码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : number : 0: 关闭成功 1:安全码错误
    """
    _method = "POST"
    _url = "/content/safeCode/close"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "safeCode": safeCode,  # 安全码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/safeCode/add")
def content_safecode_add(safeCode=None, headers=None, **kwargs):
    """
    安全码新增-Y
    up_time=1675748271

    params: safeCode : string : 安全码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : true成功; false失败
    """
    _method = "POST"
    _url = "/content/safeCode/add"

    _headers = {
        "Content-Type": "application/json",
        "rId": "77289A5EC1EDEB725AB1E7FCE3F8BE514091FEBE44315EC1AF6B410C415CA4E95728211641DC8DF8A7B7A7F18A080583D1531C5CFD08E7CAF62A31E86EAAA1CBF9DFE98543619DE617719D183644CA63661C5BF808740BB5896D90EAE4A8DF81BA090FE05C138F43749CF88F78705E998A8FBACF4236F70FF870F959D667B070C510EB85ED1F3D88C4A2899AB24BC166880055B41EDD9E29D8F19EAD763D3585C6B51D585A8E4DEE6F34847A71A1F65E48576CDADC1F5D5E6D8C249E8405333081C1A3FAF55A0F2CC3EB21F01123873A ",
        "system": "iOS",
        "aId": "77289A5EC1EDEB725AB1E7FCE3F8BE514091FEBE44315EC1AF6B410C415CA4E95728211641DC8DF8A7B7A7F18A080583D1531C5CFD08E7CAF62A31E86EAAA1CBF9DFE98543619DE617719D183644CA63661C5BF808740BB5896D90EAE4A8DF81BA090FE05C138F43749CF88F78705E998A8FBACF4236F70FF870F959D667B070C510EB85ED1F3D88C4A2899AB24BC166880055B41EDD9E29D8F19EAD763D3585C6B51D585A8E4DEE6F34847A71A1F65E48576CDADC1F5D5E6D8C249E8405333081C1A3FAF55A0F2CC3EB21F01123873A ",
    }
    _headers.update({"headers": headers})

    _data = {
        "safeCode": safeCode,  # 安全码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/safeCode/verify")
def content_safecode_verify(safeCode=None, headers=None, **kwargs):
    """
    安全码校验-Y
    up_time=1675748319

    params: safeCode :  : 安全码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : number : 0:校验成功 1:安全码错误 2:已锁定
    """
    _method = "GET"
    _url = "/content/safeCode/verify"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "safeCode": safeCode,  # 安全码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/safeCode/getStatus")
def content_safecode_getstatus( headers=None, **kwargs):
    """
    安全码状态查询-Y
    up_time=1675748015

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              mobile : string : 手机号
              status : number : 安全码状态(0:未设置 1:已设置)
              isNeedGuide : number : 是否需要指引(0:不需要 1:需要)
    """
    _method = "GET"
    _url = "/content/safeCode/getStatus"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/safeCode/reset")
def content_safecode_reset(safeCode=None, headers=None, **kwargs):
    """
    安全码重置-Y
    up_time=1675748330

    params: safeCode : string : 安全码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : number : 0:安全码重置成功  1:新密码和旧密码相同 
    """
    _method = "POST"
    _url = "/content/safeCode/reset"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "safeCode": safeCode,  # 安全码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.radarpoints.asserts_radarpoints_pointstask import AssertsRadarpointsPointstask
from service.app_a.apis.radarpoints import apis_radarpoints_pointstask


class FunsRadarpointsPointstask(AssertsRadarpointsPointstask):
    @allure.step(title="积分任务 - 分页查询")
    def radarpoints_pointstask_pagelist(self, size=10, dateLast="$None$", getPointsQtySort="$None$", pointsConfigName="$None$", pointsTaskDateSort="$None$", mobile="$None$", pointsConfigCode="$None$", current=1, dateBegin="$None$", _assert=True,  **kwargs):
        """
            url=/radarpoints/pointsTask/pageList
                params: dateBegin :  : 开始日期
                params: dateLast :  : 结束日期
                params: pointsConfigCode :  : 任务编码
                params: pointsConfigName :  : 任务名称
                params: mobile :  : 用户手机号
                params: pointsTaskDateSort :  : 日期排序字段，"ASC"升序，"DESC"降序
                params: getPointsQtySort :  : 积分值排序字段，"ASC"升序，"DESC"降序
                params: current :  : 页码
                params: size :  : 每页大小
                params: headers : 请求头
        """
        dateLast = self.get_list_choice(dateLast, list_or_dict=None, key="dateLast")
        getPointsQtySort = self.get_list_choice(getPointsQtySort, list_or_dict=None, key="getPointsQtySort")
        pointsConfigName = self.get_list_choice(pointsConfigName, list_or_dict=None, key="pointsConfigName")
        pointsTaskDateSort = self.get_list_choice(pointsTaskDateSort, list_or_dict=None, key="pointsTaskDateSort")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        pointsConfigCode = self.get_list_choice(pointsConfigCode, list_or_dict=None, key="pointsConfigCode")
        dateBegin = self.get_list_choice(dateBegin, list_or_dict=None, key="dateBegin")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_pointstask.radarpoints_pointstask_pagelist(**_kwargs)

        self.assert_radarpoints_pointstask_pagelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="积分任务 - 导出excel")
    def radarpoints_pointstask_export(self, dateLast="$None$", getPointsQtySort="$None$", pointsConfigName="$None$", pointsTaskDateSort="$None$", mobile="$None$", pointsConfigCode="$None$", dateBegin="$None$", _assert=True,  **kwargs):
        """
            url=/radarpoints/pointsTask/export
                params: dateBegin :  : 开始日期
                params: dateLast :  : 结束日期
                params: pointsConfigCode :  : 任务编码
                params: pointsConfigName :  : 任务名称
                params: mobile :  : 用户手机号
                params: pointsTaskDateSort :  : 日期排序字段，"ASC"升序，"DESC"降序
                params: getPointsQtySort :  : 积分值排序字段，"ASC"升序，"DESC"降序
                params: headers : 请求头
        """
        dateLast = self.get_list_choice(dateLast, list_or_dict=None, key="dateLast")
        getPointsQtySort = self.get_list_choice(getPointsQtySort, list_or_dict=None, key="getPointsQtySort")
        pointsConfigName = self.get_list_choice(pointsConfigName, list_or_dict=None, key="pointsConfigName")
        pointsTaskDateSort = self.get_list_choice(pointsTaskDateSort, list_or_dict=None, key="pointsTaskDateSort")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        pointsConfigCode = self.get_list_choice(pointsConfigCode, list_or_dict=None, key="pointsConfigCode")
        dateBegin = self.get_list_choice(dateBegin, list_or_dict=None, key="dateBegin")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_pointstask.radarpoints_pointstask_export(**_kwargs)

        self.assert_radarpoints_pointstask_export(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import pytest


def pytest_configure(config):
    config.addinivalue_line("markers", "smoke:冒烟用例")
    config.addinivalue_line("markers", "success:正向用例")
    config.addinivalue_line("markers", "failed:逆向用例")
    config.addinivalue_line("markers", "get:查询用例")
    config.addinivalue_line("markers", "fun:功能用例")




import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_material import SqlsContentMaterial


class AssertsContentMaterial(SqlsContentMaterial):
    @allure.step(title="接口返回结果校验")
    def assert_content_material_delgroup(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_material_delgroup(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["groupId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_material_delmaterial(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_material_delmaterial(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_material_updategroup(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_material_updategroup(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["groupName", "groupId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_material_getmateriallist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_material_getmateriallist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["groupId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_material_addgroup(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_material_addgroup(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["groupName"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_material_addmaterial(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_material_addmaterial(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["file", "groupId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_material_getgrouplist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_material_getgrouplist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["groupName"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a.asserts.goods.asserts_goods_testdrive import AssertsGoodsTestdrive
from service.app_a.apis.goods import apis_goods_testdrive


class FunsGoodsTestdrive(AssertsGoodsTestdrive):
    @allure.step(title="试驾列表文件导出接口-Y")
    def goods_testdrive_driveexports(self, exportType="$None$", shopName="$None$", userName="$None$", channel="$None$", endTime="$None$", mobile="$None$", testDriveIdStr="$None$", startTime="$None$", _assert=True,  **kwargs):
        """
            url=/goods/testDrive/driveExports
                params: mobile :  : 手机号
                params: userName :  : 用户名
                params: shopName :  : 店名
                params: channel :  : 渠道
                params: startTime :  : 开始时间
                params: endTime :  : 结束时间
                params: exportType :  : 导出类型
                params: testDriveIdStr :  : 订单集合字符串
                params: headers : 请求头
        """
        exportType = self.get_list_choice(exportType, list_or_dict=None, key="exportType")
        shopName = self.get_list_choice(shopName, list_or_dict=None, key="shopName")
        userName = self.get_list_choice(userName, list_or_dict=None, key="userName")
        channel = self.get_list_choice(channel, list_or_dict=None, key="channel")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        testDriveIdStr = self.get_list_choice(testDriveIdStr, list_or_dict=None, key="testDriveIdStr")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_testdrive.goods_testdrive_driveexports(**_kwargs)

        self.assert_goods_testdrive_driveexports(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="试驾查询接口-Y")
    def goods_testdrive_page(self, shopName="$None$", userName="$None$", pageNum=1, channel="$None$", endTime="$None$", pageSize="$None$", mobile="$None$", startTime="$None$", _assert=True,  **kwargs):
        """
            url=/goods/testDrive/page
                params: mobile :  : 手机号
                params: userName :  : 客户名
                params: shopName :  : 店名
                params: channel :  : 渠道
                params: startTime :  : 开始时间
                params: endTime :  : 结束时间
                params: pageNum :  : 当前页数
                params: pageSize :  : 每页数据数
                params: headers : 请求头
        """
        shopName = self.get_list_choice(shopName, list_or_dict=None, key="shopName")
        userName = self.get_list_choice(userName, list_or_dict=None, key="userName")
        channel = self.get_list_choice(channel, list_or_dict=None, key="channel")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        pageSize = self.get_list_choice(pageSize, list_or_dict=None, key="pageSize")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_testdrive.goods_testdrive_page(**_kwargs)

        self.assert_goods_testdrive_page(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.content.asserts_content_material import AssertsContentMaterial
from service.app_a.apis.content import apis_content_material
from service.app_a.funs.content.material.funs_content_material_getmateriallist import FunsContentMaterialGetmateriallist


class FunsContentMaterial(AssertsContentMaterial, FunsContentMaterialGetmateriallist):
    @allure.step(title="素材-删除分组-Y")
    def content_material_delgroup(self, groupId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/material/delGroup
                params: groupId : number : 素材分组主键
                params: headers : 请求头
        """
        groupId = self.get_value_choice(groupId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_material.content_material_delgroup(**_kwargs)

        self.assert_content_material_delgroup(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="素材-批量删除")
    def content_material_delmaterial(self, _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/material/delMaterial
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_material.content_material_delmaterial(**_kwargs)

        self.assert_content_material_delmaterial(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="素材-更新素材分组-Y")
    def content_material_updategroup(self, groupName="$None$", groupId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/material/updateGroup
                params: groupName : string : 分组名称
                params: groupId : number : 分组主键
                params: headers : 请求头
        """
        groupName = self.get_value_choice(groupName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        groupId = self.get_value_choice(groupId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_material.content_material_updategroup(**_kwargs)

        self.assert_content_material_updategroup(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="素材-根据素材组获取素材列表")
    def content_material_getmateriallist(self, size=10, groupId="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/content/material/getMaterialList
                params: groupId :  : 分组主键
                params: size :  : 每页数据数
                params: current :  : 当前页
                params: headers : 请求头
        """
        groupId = self.get_list_choice(groupId, list_or_dict=None, key="groupId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_material.content_material_getmateriallist(**_kwargs)

        self.assert_content_material_getmateriallist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="素材-添加素材分组-Y")
    def content_material_addgroup(self, groupName="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/material/addGroup
                params: groupName : string : 分组名称
                params: headers : 请求头
        """
        groupName = self.get_value_choice(groupName, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_material.content_material_addgroup(**_kwargs)

        self.assert_content_material_addgroup(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="素材-素材上传")
    def content_material_addmaterial(self, file="$None$", groupId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/material/addMaterial
                params: file : file : 上传文件
                params: groupId : text : 所属分组主键
                params: headers : 请求头
        """
        file = self.get_value_choice(file, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        groupId = self.get_value_choice(groupId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_material.content_material_addmaterial(**_kwargs)

        self.assert_content_material_addmaterial(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="素材-素材组列表-Y")
    def content_material_getgrouplist(self, groupName="$None$", _assert=True,  **kwargs):
        """
            url=/content/material/getGroupList
                params: groupName :  :
                params: headers : 请求头
        """
        groupName = self.get_list_choice(groupName, list_or_dict=None, key="groupName")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_material.content_material_getgrouplist(**_kwargs)

        self.assert_content_material_getgrouplist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.common.sqls_common_user4c import SqlsCommonUser4C


class AssertsCommonUser4C(SqlsCommonUser4C):
    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_queryactivitysource(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_queryactivitysource(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId", "lastLoginTimeEnd", "createTimeStart", "nickName", "memberSystemSource", "userSystemSource", "createTimeEnd", "regisTimeEnd", "lastLoginTimeStart", "mobile", "ownerFlag", "regisTimeBegin", "activitySource", "status", "type"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_vehicleinfo(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_vehicleinfo(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId", "mobile"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_getbyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_getbyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_updateuser(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_updateuser(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_download(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_download(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId", "lastLoginTimeEnd", "userIds", "createTimeStart", "nickName", "memberSystemSource", "userSystemSource", "createTimeEnd", "regisTimeEnd", "lastLoginTimeStart", "mobile", "downloadType", "ownerFlag", "regisTimeBegin", "activitySource", "status", "type"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_beforepointsexport(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_beforepointsexport(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId", "lastLoginTimeEnd", "userIds", "createTimeStart", "nickName", "memberSystemSource", "userSystemSource", "createTimeEnd", "regisTimeEnd", "lastLoginTimeStart", "mobile", "downloadType", "ownerFlag", "regisTimeBegin", "activitySource", "status", "type"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_insert(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_insert(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["explain", "avatarUrl", "nickName"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_editstatus(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_editstatus(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId", "status"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_auditexport(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_auditexport(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId", "userIds", "registerType", "userLabel", "phone", "userType", "downloadType", "ownerFlag", "nickName"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_identity(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_identity(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_updateaudit(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_updateaudit(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId", "auditType"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_auditlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_auditlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId", "userName", "registerType", "pageNum", "mobile", "checkStatus", "nickName"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_user4c_getuserpoints(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_user4c_getuserpoints(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/area/getCityList")
def area_getcitylist( headers=None, **kwargs):
    """
    限行城市-D
    up_time=1675385527

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : null : 
              maxLimit : null : 
              pages : number : 
    """
    _method = "GET"
    _url = "/area/getCityList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/order/testDrive/exportList")
def order_testdrive_exportlist(createByName=None, createTime=None, shopName=None, phoneNumber=None, channel=None, endTime=None, id=None, startTime=None, headers=None, **kwargs):
    """
    导出试驾表单-Y
    up_time=1675417182

    params: phoneNumber :  : 手机号
    params: createByName :  : 
    params: id :  : 主键
    params: channel :  : 渠道(1:移动应用 2:小程序 3:官方网站)
    params: startTime :  : 
    params: endTime :  : 
    params: shopName :  : 门店名称
    params: createTime :  : 创建时间
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/order/testDrive/exportList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "phoneNumber": phoneNumber,  # 手机号
        "createByName": createByName,
        "id": id,  # 主键
        "channel": channel,  # 渠道(1:移动应用 2:小程序 3:官方网站)
        "startTime": startTime,
        "endTime": endTime,
        "shopName": shopName,  # 门店名称
        "createTime": createTime,  # 创建时间
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/testDrive/userList")
def order_testdrive_userlist(modelId=None, size=None, current=None, createBy=None, headers=None, **kwargs):
    """
    用户中心-预约信息
    up_time=1675417772

    params: current :  : 当前页数
    params: size :  : 每页数据数
    params: createBy :  : 
    params: modelId :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : string : 
              size : string : 
              current : string : 
    """
    _method = "GET"
    _url = "/order/testDrive/userList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,  # 当前页数
        "size": size,  # 每页数据数
        "createBy": createBy,
        "modelId": modelId,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/order/freeOrder/downLoad")
def order_freeorder_download(userPolicyCode=None, createTime=None, regisTimeBegin=None, avatarUrl=None, userName=None, privacyPolicyCode=None, regisTimeEnd=None, channel=None, freeOrderId=None, cityId=None, mobile=None, provinceId=None, cityName=None, modelId=None, channelName=None, nickName=None, provinceName=None, headers=None, **kwargs):
    """
    导出0元订购预定信息表-Y
    up_time=1675318920

    params: freeOrderId : integer : 订单号
    params: modelId : string : 车型编码
    params: userName : string : 用户姓名
    params: mobile : string : 用户号码
    params: provinceId : string : 省编码
    params: provinceName : string : 省
    params: cityId : string : 市编码
    params: cityName : string : 市
    params: channel : string : 渠道 0 官网 1 app
    params: channelName : string : 
    params: createTime : string : 订单创建时间
    params: regisTimeBegin : string : 开始时间
    params: regisTimeEnd : string : 结束时间
    params: nickName : string : 昵称
    params: avatarUrl : string : 头像
    params: userPolicyCode : string : 用户协议版本号
    params: privacyPolicyCode : string : 隐私协议版本号
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/order/freeOrder/downLoad"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "freeOrderId": freeOrderId,  # 订单号
        "modelId": modelId,  # 车型编码
        "userName": userName,  # 用户姓名
        "mobile": mobile,  # 用户号码
        "provinceId": provinceId,  # 省编码
        "provinceName": provinceName,  # 省
        "cityId": cityId,  # 市编码
        "cityName": cityName,  # 市
        "channel": channel,  # 渠道 0 官网 1 app
        "channelName": channelName,
        "createTime": createTime,  # 订单创建时间
        "regisTimeBegin": regisTimeBegin,  # 开始时间
        "regisTimeEnd": regisTimeEnd,  # 结束时间
        "nickName": nickName,  # 昵称
        "avatarUrl": avatarUrl,  # 头像
        "userPolicyCode": userPolicyCode,  # 用户协议版本号
        "privacyPolicyCode": privacyPolicyCode,  # 隐私协议版本号
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.goods.sqls_goods_testdrive import SqlsGoodsTestdrive


class AssertsGoodsTestdrive(SqlsGoodsTestdrive):
    @allure.step(title="接口返回结果校验")
    def assert_goods_testdrive_driveexports(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_testdrive_driveexports(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["exportType", "shopName", "userName", "channel", "endTime", "mobile", "testDriveIdStr", "startTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_testdrive_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_testdrive_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["shopName", "userName", "pageNum", "channel", "endTime", "mobile", "startTime"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_comment import SqlsContentComment


class AssertsContentComment(SqlsContentComment):
    @allure.step(title="接口返回结果校验")
    def assert_content_comment_updatestatus(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_comment_updatestatus(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["fromStatus", "commentId", "toStatus", "commentType"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_comment_download(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_comment_download(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["nickName", "keyWord", "contentCommentIds", "endTime", "EssayCommentIds", "status", "mobile", "downloadType", "startTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_comment_commenttop(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_comment_commenttop(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["commentId", "topFlag", "commentType"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_comment_list(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_comment_list(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["nickName", "keyWord", "endTime", "commentType", "checkedStatus", "mobile", "essayId", "startTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_comment_delete(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_comment_delete(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["commentId", "toStatus", "commentType"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a.asserts.content.asserts_content_comment import AssertsContentComment
from service.app_a.apis.content import apis_content_comment


class FunsContentComment(AssertsContentComment):
    @allure.step(title="评论-状态扭转（通用）-Y")
    def content_comment_updatestatus(self, fromStatus="$None$", commentId="$None$", toStatus="$None$", commentType="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/comment/updateStatus
                params: commentId :  : 评论主键
                params: commentType :  : 评论类型1：文章评论2：动态评论
                params: fromStatus :  : 当前状态
                params: toStatus :  : 扭转状态
                params: headers : 请求头
        """
        fromStatus = self.get_value_choice(fromStatus, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        commentId = self.get_value_choice(commentId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        toStatus = self.get_value_choice(toStatus, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        commentType = self.get_value_choice(commentType, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_comment.content_comment_updatestatus(**_kwargs)

        self.assert_content_comment_updatestatus(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="评论-评论导出-Y")
    def content_comment_download(self, nickName="$None$", keyWord="$None$", contentCommentIds="$None$", endTime="$None$", EssayCommentIds="$None$", status="$None$", mobile="$None$", downloadType="$None$", startTime="$None$", _assert=True,  **kwargs):
        """
            url=/content/comment/downLoad
                params: mobile :  : 评论用户手机号
                params: nickName :  : 评论昵称
                params: keyWord :  : 搜索关键字
                params: startTime :  : 搜索起始时间
                params: endTime :  : 搜索结束时间
                params: status :  : 状态0.待审核 1.已审核 2.审核未通过3：已发布4：已屏蔽
                params: downloadType :  : 1：根据搜索条件导出2：多选导出
                params: EssayCommentIds :  : 文章评论主键，用英文,隔开
                params: contentCommentIds :  : 动态评论主键，用英文,隔开
                params: headers : 请求头
        """
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")
        keyWord = self.get_list_choice(keyWord, list_or_dict=None, key="keyWord")
        contentCommentIds = self.get_list_choice(contentCommentIds, list_or_dict=None, key="contentCommentIds")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        EssayCommentIds = self.get_list_choice(EssayCommentIds, list_or_dict=None, key="EssayCommentIds")
        status = self.get_list_choice(status, list_or_dict=None, key="status")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        downloadType = self.get_list_choice(downloadType, list_or_dict=None, key="downloadType")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_comment.content_comment_download(**_kwargs)

        self.assert_content_comment_download(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="评论-评论置顶（通用）-Y")
    def content_comment_commenttop(self, commentId="$None$", topFlag="$None$", commentType="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/comment/commentTop
                params: commentId : string : 评论主键
                params: commentType : number : 评论类型1：文章评论2：动态评论
                params: topFlag : number : 1：置顶0：取消置顶
                params: headers : 请求头
        """
        commentId = self.get_value_choice(commentId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        topFlag = self.get_value_choice(topFlag, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        commentType = self.get_value_choice(commentType, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_comment.content_comment_commenttop(**_kwargs)

        self.assert_content_comment_commenttop(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="后台管理-评论管理列表1030-Y")
    def content_comment_list(self, size=10, nickName="$None$", keyWord="$None$", endTime="$None$", commentType="$None$", checkedStatus="$None$", mobile="$None$", essayId="$None$", startTime="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/content/comment/list
                params: nickName :  : 用户昵称 String
                params: keyWord :  : 搜索内容关键字  String
                params: startTime :  : 搜索开始时间 yyyy-MM-dd HH:mm:ss
                params: endTime :  : 搜索结束时间 yyyy-MM-dd HH:mm:ss
                params: size :  : 每页数量数
                params: current :  : 当前页
                params: commentType :  : 评论类型1：文章评论 2：动态 Integer
                params: checkedStatus :  : 审核状态 0待审核 1.已上架 2.审核未通过3：已发布 5已删除 Integer
                params: mobile :  : 电话 string
                params: essayId :  : 文章(资讯)主键 string
                params: headers : 请求头
        """
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")
        keyWord = self.get_list_choice(keyWord, list_or_dict=None, key="keyWord")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        commentType = self.get_list_choice(commentType, list_or_dict=None, key="commentType")
        checkedStatus = self.get_list_choice(checkedStatus, list_or_dict=None, key="checkedStatus")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        essayId = self.get_list_choice(essayId, list_or_dict=None, key="essayId")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_comment.content_comment_list(**_kwargs)

        self.assert_content_comment_list(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="评论-屏蔽评论-Y")
    def content_comment_delete(self, commentId="$None$", toStatus="$None$", commentType="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/comment/delete
                params: commentId : string : 评论主键
                params: commentType : number : 1：文章评论2：动态评论
                params: toStatus : string :
                params: headers : 请求头
        """
        commentId = self.get_value_choice(commentId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        toStatus = self.get_value_choice(toStatus, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        commentType = self.get_value_choice(commentType, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_comment.content_comment_delete(**_kwargs)

        self.assert_content_comment_delete(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_essayweb import SqlsContentEssayweb


class AssertsContentEssayweb(SqlsContentEssayweb):
    @allure.step(title="接口返回结果校验")
    def assert_content_essayweb_add(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essayweb_add(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["publishChannel", "essPicUrl", "publishType", "author", "essayId", "title", "content", "status", "publishTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essayweb_searchbykey(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essayweb_searchbykey(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["key"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essayweb_delete_(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essayweb_delete_(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essayweb_getbyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essayweb_getbyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["subjectId", "essayId"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/commonquestion/updateStatus")
def content_commonquestion_updatestatus(status=None, essayId=None, headers=None, **kwargs):
    """
    常见问题-上下架-Y
    up_time=1675681221

    params: essayId :  : 主键id
    params: status : string : 上架2 下架3
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0 成功 1失败
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/content/commonquestion/updateStatus"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 主键id
        "status": status,  # 上架2 下架3
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/commonquestion/update")
def content_commonquestion_update(title=None, content=None, essayId=None, headers=None, **kwargs):
    """
    常见问题-修改-Y
    up_time=1675681308

    params: essayId :  : 主键id
    params: title : string : 标题
    params: content : string : 内容
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0 成功 1失败
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/content/commonquestion/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 主键id
        "title": title,  # 标题
        "content": content,  # 内容
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/commonquestion/updateRank")
def content_commonquestion_updaterank(rank=None, essayId=None, headers=None, **kwargs):
    """
    常见问题-修改权重-Y
    up_time=1675681234

    params: essayId :  : 主键id
    params: rank : string : 权重
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0 成功 1失败
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/content/commonquestion/updateRank"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 主键id
        "rank": rank,  # 权重
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/commonquestion/delete")
def content_commonquestion_delete(essayId=None, headers=None, **kwargs):
    """
    常见问题-删除-Y
    up_time=1675681073

    params: essayId :  : 主键id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0 成功 1失败 
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/content/commonquestion/delete"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 主键id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/commonquestion/list")
def content_commonquestion_list(size=None, current=None, headers=None, **kwargs):
    """
    常见问题-后台列表-Y
    up_time=1675681018

    params: current :  : 当前页数
    params: size :  : 每页个数
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              pages : number : 
    """
    _method = "GET"
    _url = "/content/commonquestion/list"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,  # 当前页数
        "size": size,  # 每页个数
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/commonquestion/publishList")
def content_commonquestion_publishlist(size=None, current=None, headers=None, **kwargs):
    """
    常见问题-已发布列表-Y
    up_time=1675681033

    params: current :  : 当前页数
    params: size :  : 每页数量
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              pages : number : 
    """
    _method = "GET"
    _url = "/content/commonquestion/publishList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,  # 当前页数
        "size": size,  # 每页数量
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/commonquestion/add")
def content_commonquestion_add(title=None, content=None, essayId=None, headers=None, **kwargs):
    """
    常见问题-新增-Y
    up_time=1675681275

    params: essayId :  : 主键id
    params: title : string : 标题
    params: content : string : 内容
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0 成功 1失败
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/content/commonquestion/add"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 主键id
        "title": title,  # 标题
        "content": content,  # 内容
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/commonquestion/createId")
def content_commonquestion_createid( headers=None, **kwargs):
    """
    常见问题-生成id-Y
    up_time=1675681168

    params: headers : 请求头
    ====================返回======================
    params: code : number : 0 成功 1失败
    params: msg : string : 
    params: data : string : 生成的id
    """
    _method = "GET"
    _url = "/content/commonquestion/createId"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/commonquestion/info")
def content_commonquestion_info(essayId=None, headers=None, **kwargs):
    """
    常见问题-详情-Y
    up_time=1675681050

    params: essayId :  : 主键id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              essayId : string : 主键id
              title : string : 标题
              content : string : 内容
              status : number : 状态1：未上架 2：已上架3：已下架 4：已删除
              updateTime : string : 编辑时间
              updateBy : null : 编辑人
              updateByName : null : 编辑人姓名
              publishTime : string : 发布时间
              rank : number : 权重
              delFlag : number :  0 正常 1删除
    """
    _method = "GET"
    _url = "/content/commonquestion/info"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 主键id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.radarpoints.adjustpoints.adjust.asserts_radarpoints_adjustpoints_adjust_batch import AssertsRadarpointsAdjustpointsAdjustBatch
from service.app_a.apis.radarpoints.adjustpoints.adjust import apis_radarpoints_adjustpoints_adjust_batch


class FunsRadarpointsAdjustpointsAdjustBatch(AssertsRadarpointsAdjustpointsAdjustBatch):
    @allure.step(title="积分调整 - 批量调整")
    def radarpoints_adjustpoints_adjust_batch_save(self, file="$None$", clientNotes="$None$", adjustNotes="$None$", redisKey="$None$", optAbility="$None$", optAbilityName="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/radarpoints/adjustPoints/adjust/batch/save
                params: file : file : 导入excel文件
                params: optAbility : text : 调整方式
                params: adjustNotes : text : 调整原因说明
                params: clientNotes : text : 用户端展示
                params: optAbilityName : string : 调整方式枚举
                params: redisKey : string : 缓存键
                params: headers : 请求头
        """
        file = self.get_value_choice(file, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        clientNotes = self.get_value_choice(clientNotes, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        adjustNotes = self.get_value_choice(adjustNotes, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        redisKey = self.get_value_choice(redisKey, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        optAbility = self.get_value_choice(optAbility, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        optAbilityName = self.get_value_choice(optAbilityName, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_adjustpoints_adjust_batch.radarpoints_adjustpoints_adjust_batch_save(**_kwargs)

        self.assert_radarpoints_adjustpoints_adjust_batch_save(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="积分调整 - 批量调整 - 导入excel")
    def radarpoints_adjustpoints_adjust_batch_import(self, file="$None$", clientNotes="$None$", adjustNotes="$None$", field_35="$None$", list="$None$", field_34="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/radarpoints/adjustPoints/adjust/batch/import
                params: file : file : excel文件
                params: adjustNotes : string : 调整原因说明
                params: clientNotes : string : 客户端显示信息
                params: list : array : 成功数据集
                userId : number : 用户id
                adjustTypeName : number : 调整类型名称
                adjustNumber : number : 调整数值
                pointsDepartment : number : 积分归属部门
                DateType : number : 生效时间类型
                params: field_35 : string :
                params: field_34 : string :
                params: headers : 请求头
        """
        file = self.get_value_choice(file, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        clientNotes = self.get_value_choice(clientNotes, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        adjustNotes = self.get_value_choice(adjustNotes, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        field_35 = self.get_value_choice(field_35, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        list = self.get_value_choice(list, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        field_34 = self.get_value_choice(field_34, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_adjustpoints_adjust_batch.radarpoints_adjustpoints_adjust_batch_import(**_kwargs)

        self.assert_radarpoints_adjustpoints_adjust_batch_import(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.goods.sqls_goods_configure import SqlsGoodsConfigure


class AssertsGoodsConfigure(SqlsGoodsConfigure):
    @allure.step(title="接口返回结果校验")
    def assert_goods_configure_savecarconfigure(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_configure_savecarconfigure(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["processColorList", "optionalList", "salesVersionList", "appearanceColorList", "interiorColorList"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_configure_getcarconfigurename(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_configure_getcarconfigurename(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["modelId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_configure_removecarconfigure(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_configure_removecarconfigure(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["configureId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_configure_updatecarconfigurestatus(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_configure_updatecarconfigurestatus(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["configureId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_configure_info(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_configure_info(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["modelId"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/recruit/save")
def content_recruit_save(fileUrl=None, fileName=None, headers=None, **kwargs):
    """
    招聘信息保存-Y
    up_time=1675740268

    params: fileName : string : 文件名
    params: fileUrl : string : 文件url
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0:成功   1:失败
    params: msg : string : 信息
    params: data : boolean : true成功;  false失败
    """
    _method = "POST"
    _url = "/content/recruit/save"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "fileName": fileName,  # 文件名
        "fileUrl": fileUrl,  # 文件url
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/recruit/detail")
def content_recruit_detail( headers=None, **kwargs):
    """
    招聘信息查询-Y
    up_time=1675740254

    params: headers : 请求头
    ====================返回======================
    params: code : number : 0:成功  1:失败
    params: msg : string : 信息
    params: data : object : 
              recruitId : string : 
              fileName : string : 文件名
              fileUrl : string : 文件url
              createTime : string : 
              createBy : string : 
              updateTime : string : 
              updateBy : string : 
              delFlag : number : 
    """
    _method = "GET"
    _url = "/content/recruit/detail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





from huhk.init_project import GetApi
from huhk.unit_request import UnitRequest


class Request(UnitRequest):
    pass


APP_KEY = "4ab5ebca-77d6-470e-9a3d-417f917ea85f"


unit_request = Request("SIT", APP_KEY)
# 环境变量
variable = unit_request.variable
http_requester = unit_request.http_requester


if __name__ == "__main__":
    GetApi(name='app_a', app_key=APP_KEY).create_or_update_project()
